--tables
CREATE TABLE IF NOT EXISTS activity (
            _id INTEGER PRIMARY KEY AUTOINCREMENT,
            sa_platform_id  TEXT,
            sa_workout_id  TEXT,
            sa_app_id TEXT NOT NULL,
            sa_start_utc_millis INTEGER NOT NULL,
            sa_end_utc_millis INTEGER NOT NULL,
            sa_active_duration_millis INTEGER,
            sa_last_modified_millis INTEGER NOT NULL,
            sa_type TEXT COLLATE NOCASE NOT NULL,
            sa_metrics TEXT COLLATE NOCASE,
            sa_user_category TEXT,
            sa_deleted INTEGER DEFAULT 0 NOT NULL,
            sa_sync_status INTEGER DEFAULT 0 NOT NULL,
            sa_workout_srvc_sync_status INTEGER DEFAULT 2 NOT NULL,
            CONSTRAINT activity_unique UNIQUE (
                    sa_platform_id) ON CONFLICT ABORT);

CREATE TABLE IF NOT EXISTS activity_summary (
            _id INTEGER PRIMARY KEY AUTOINCREMENT,
            as_type TEXT COLLATE NOCASE NOT NULL,
            as_metric_type TEXT COLLATE NOCASE NOT NULL,
            as_value REAL NOT NULL,
            as_app_id TEXT,
            as_source TEXT NOT NULL,
            s_activity_id INTEGER NOT NULL,
            FOREIGN KEY(s_activity_id) REFERENCES activity (_id) ON DELETE CASCADE,
            CONSTRAINT activity_summary_unique UNIQUE (as_type, as_metric_type, s_activity_id)
            ON CONFLICT REPLACE);

CREATE TABLE IF NOT EXISTS activity_source (
            _id INTEGER PRIMARY KEY AUTOINCREMENT,
            asrc_activity_id INTEGER NOT NULL,
            asrc_source TEXT COLLATE NOCASE NOT NULL,
            FOREIGN KEY(asrc_activity_id) REFERENCES activity (_id) ON DELETE CASCADE,
            CONSTRAINT activity_source_unique UNIQUE (asrc_activity_id, asrc_source) ON CONFLICT REPLACE);

CREATE TABLE IF NOT EXISTS activity_change_token (
            _id INTEGER PRIMARY KEY AUTOINCREMENT,
            acs_activity_id INTEGER NOT NULL,
            acs_change_token TEXT COLLATE NOCASE NOT NULL,
            FOREIGN KEY(acs_activity_id) REFERENCES activity (_id) ON DELETE CASCADE,
            CONSTRAINT activity_change_token_unique UNIQUE (acs_activity_id, acs_change_token) ON CONFLICT REPLACE);

CREATE TABLE IF NOT EXISTS activity_tag (
            _id INTEGER PRIMARY KEY AUTOINCREMENT,
            t_type TEXT COLLATE NOCASE NOT NULL,
            t_value TEXT,
            s_sport_activity_id INTEGER NOT NULL,
            FOREIGN KEY(s_sport_activity_id) REFERENCES activity (_id) ON DELETE CASCADE,
            CONSTRAINT activity_tag_unique UNIQUE (t_type, s_sport_activity_id) ON CONFLICT REPLACE);

CREATE TABLE IF NOT EXISTS activity_moment (
            _id INTEGER PRIMARY KEY AUTOINCREMENT,
            m_type TEXT COLLATE NOCASE NOT NULL,
            m_value TEXT NOT NULL,
            m_timestamp_utc_millis INTEGER NOT NULL,
            m_app_id TEXT,
            m_source TEXT NOT NULL,
            m_activity_id INTEGER NOT NULL,
            FOREIGN KEY(m_activity_id) REFERENCES activity (_id) ON DELETE CASCADE);

CREATE TABLE IF NOT EXISTS activity_metric_group (
            _id INTEGER PRIMARY KEY AUTOINCREMENT,
            mg_source TEXT COLLATE NOCASE NOT NULL,
            mg_unit TEXT COLLATE NOCASE NOT NULL,
            mg_activity_id INTEGER,
            mg_metric_type TEXT COLLATE NOCASE NOT NULL,
            app_id TEXT COLLATE NOCASE NOT NULL,
            FOREIGN KEY( mg_activity_id ) REFERENCES activity (_id) ON DELETE CASCADE,
            CONSTRAINT activity_metric_group_unique UNIQUE (mg_source, mg_metric_type,
            mg_activity_id) ON CONFLICT REPLACE);

CREATE TABLE IF NOT EXISTS activity_raw_metric (
            _id INTEGER PRIMARY KEY AUTOINCREMENT,
            rm_start_utc_millis INTEGER NOT NULL,
            rm_end_utc_millis INTEGER NOT NULL,
            rm_value REAL NOT NULL,
            rm_metric_group_id INTEGER NOT NULL,
            rm_sync_status INTEGER DEFAULT 0,
            FOREIGN KEY(rm_metric_group_id) REFERENCES activity_metric_group ( _id) ON DELETE
            CASCADE,
            CONSTRAINT activity_raw_metric_unique UNIQUE (rm_start_utc_millis,
            rm_end_utc_millis, rm_metric_group_id) ON CONFLICT REPLACE);

CREATE TABLE IF NOT EXISTS timezone (
            tz_utc_millis INTEGER PRIMARY KEY,
            tz_timezone_id TEXT COLLATE NOCASE NOT NULL,
            tz_sync_status INTEGER DEFAULT 0 NOT NULL,
            CONSTRAINT timezone_unique UNIQUE (tz_utc_millis) ON CONFLICT REPLACE);

--plan tables
CREATE TABLE IF NOT EXISTS ntc_plan (
            _id INTEGER PRIMARY KEY AUTOINCREMENT,
            p_plan_id TEXT NOT NULL UNIQUE ON CONFLICT REPLACE,
            p_source TEXT,
            p_plan_name TEXT,
            p_create_time INTEGER,
            p_start_time INTEGER,
            p_end_time INTEGER,
            p_last_adapt_time INTEGER,
            p_object_type TEXT,
            p_object_id TEXT,
            p_status INTEGER,
            p_cancel_time INTEGER,
            p_cancel_reason TEXT,
            p_complete_time INTEGER,
            p_change_token TEXT,
            p_sync_status INTEGER DEFAULT 0 NOT NULL);

CREATE TABLE IF NOT EXISTS ntc_plan_config (
            pc_p_plan_id TEXT PRIMARY KEY ON CONFLICT REPLACE,
            pc_equipment TEXT,
            pc_has_equipment INTEGER,
            pc_equipment_types TEXT,
            pc_days_per_week TEXT,
            pc_include_runs INTEGER,
            pc_training_level TEXT);

CREATE TABLE IF NOT EXISTS ntc_plan_item (
            _id INTEGER PRIMARY KEY AUTOINCREMENT,
            pi_plan_item_id TEXT NOT NULL,
            pi_p_plan_id TEXT NOT NULL,
            pi_day_of_plan INTEGER,
            pi_object_type TEXT,
            pi_object_id TEXT,
            pi_w_workout_id TEXT,
            pi_sync_status INTEGER DEFAULT 0 NOT NULL);

CREATE TABLE IF NOT EXISTS ntc_plan_item_activity (
            _id INTEGER PRIMARY KEY AUTOINCREMENT,
            pia_p_plan_item_id INTEGER NOT NULL ,
            pia_activity_local_id INTEGER,
            pia_workout_id TEXT ,
            pia_platform_activity_id TEXT ,
            pia_completion_time INTEGER DEFAULT 0,
            pia_sync_status INTEGER DEFAULT 0 NOT NULL);

CREATE TABLE IF NOT EXISTS ntc_threshold (
            t_threshold_id TEXT PRIMARY KEY ON CONFLICT REPLACE,
            t_p_plan_id TEXT NOT NULL,
            t_capture_time INTEGER);

CREATE TABLE IF NOT EXISTS ntc_threshold_value (
            tv_threshold_id TEXT NOT NULL,
            tv_value TEXT NOT NULL,
            PRIMARY KEY (tv_threshold_id, tv_value) ON CONFLICT IGNORE);