-- TABLES
ALTER TABLE ntc_workout ADD COLUMN w_publish_date INTEGER DEFAULT 0;

ALTER TABLE ntc_collection ADD COLUMN c_collection_publish_date INTEGER DEFAULT 0;

ALTER TABLE ntc_athlete ADD COLUMN a_publish_date INTEGER DEFAULT 0;

-- VIEWS
DROP VIEW v_ntc_workout;

CREATE VIEW IF NOT EXISTS v_ntc_workout AS
    SELECT w.w_workout_id AS w_workout_id,
    w.w_workout_id AS w_workout_id,
    w.w_estimated_rpe AS w_estimated_rpe,
    w.w_estimated_fuel AS w_estimated_fuel,
    w.w_estimated_kcal AS w_estimated_kcal,
    w.w_is_benchmark AS w_is_benchmark,
    w.w_duration_sec AS w_duration_sec,
    w.w_estimated_duration_sec AS w_estimated_duration_sec,
    w.w_focus AS w_focus,
    w.w_intensity AS w_intensity,
    w.w_type AS w_type,
    w.w_level AS w_level,
    w.w_equipment AS w_equipment,
    w.w_name_key AS w_name_key,
    w.w_athlete_key AS w_athlete_key,
    w.w_author_key AS w_author_key,
    w.w_quote_key AS w_quote_key,
    w.w_content_version AS w_content_version,
    w.w_intro_subtitles AS w_intro_subtitles,
    w.w_publish_date AS w_publish_date,
    s1.str_value AS w_name,
    s2.str_value AS w_author,
    s3.str_value AS w_quote,
    s4.str_value AS w_athlete,
    CASE WHEN (f.wf_workout_id NOTNULL) THEN 1 ELSE 0 END AS w_is_favorite
    FROM ntc_workout AS w
    LEFT JOIN ntc_string AS s1 ON (s1.str_key = w_name_key)
    LEFT JOIN ntc_string AS s2 ON (s2.str_key = w_author_key)
    LEFT JOIN ntc_string AS s3 ON (s3.str_key = w_quote_key)
    LEFT JOIN ntc_string AS s4 ON (s4.str_key = w_athlete_key)
    LEFT JOIN ntc_workout_favorite AS f ON f.wf_workout_id = w.w_workout_id;

DROP VIEW v_ntc_athlete;

CREATE VIEW IF NOT EXISTS v_ntc_athlete AS
    SELECT a.a_athlete_id AS a_athlete_id,
    a.a_name_key AS a_name_key,
    a.a_title_key AS a_title_key,
    a.a_tagline_key AS a_tagline_key,
    a.a_workout_summary_key AS a_workout_summary_key,
    a.a_workout_title_key AS a_workout_title_key,
    a.a_video_title_key AS a_video_title_key,
    a.a_video_subhead_key AS a_video_subhead_key,
    a.a_subtitles_key AS a_subtitles_key,
    a.a_channel_title_key AS a_channel_title_key,
    a.a_channel_id AS a_channel_id,
    a.a_product_title_key AS a_product_title_key,
    a.a_gender AS a_gender,
    a.a_workout_ids AS a_workout_ids,
    a.a_workout_layout AS a_workout_layout,
    a.a_publish_date AS a_publish_date,
    s1.str_value AS a_name,
    s2.str_value AS a_title,
    s3.str_value AS a_tagline,
    s4.str_value AS a_workout_summary,
    s9.str_value AS a_workout_title,
    s5.str_value AS a_video_title,
    s10.str_value AS a_channel_title,
    s6.str_value AS a_video_subhead,
    s8.str_value AS a_product_title
    FROM ntc_athlete AS a
    LEFT JOIN ntc_string AS s1 ON (s1.str_key = a_name_key)
    LEFT JOIN ntc_string AS s2 ON (s2.str_key = a_title_key)
    LEFT JOIN ntc_string AS s3 ON (s3.str_key = a_tagline_key)
    LEFT JOIN ntc_string AS s4 ON (s4.str_key = a_workout_summary_key)
    LEFT JOIN ntc_string AS s5 ON (s5.str_key = a_video_title_key)
    LEFT JOIN ntc_string AS s6 ON (s6.str_key = a_video_subhead_key)
    LEFT JOIN ntc_string AS s8 ON (s8.str_key = a_product_title_key)
    LEFT JOIN ntc_string AS s9 ON (s9.str_key = a_workout_title_key)
    LEFT JOIN ntc_string AS s10 ON (s10.str_key = a_channel_title_key);

DROP VIEW v_ntc_collection;

CREATE VIEW IF NOT EXISTS v_ntc_collection AS
    SELECT c.c_collection_id AS c_collection_id,
    c.c_collection_title_key AS c_collection_title_key,
    c.c_collection_summary_key AS c_collection_summary_key,
    c.c_collection_overview_title_key AS c_collection_overview_title_key,
    c.c_collection_overview_summary_key AS c_collection_overview_summary_key,
    c.c_collection_workouts_title_key AS c_collection_workouts_title_key,
    c.c_collection_workouts_summary_key AS c_collection_workouts_summary_key,
    c.c_collection_workouts_two_title_key AS c_collection_workouts_two_title_key,
    c.c_collection_workouts_two_summary_key AS c_collection_workouts_two_summary_key,
    c.c_collection_workouts_three_title_key AS c_collection_workouts_three_title_key,
    c.c_collection_workouts_three_summary_key AS c_collection_workouts_three_summary_key,
    c.c_collection_heading_key AS c_collection_heading_key,
    c.c_collection_training_note_key AS c_collection_training_note_key,
    c.c_collection_attribution_name_key AS c_collection_attribution_name_key,
    c.c_collection_attribution_title_key AS c_collection_attribution_title_key,
    c.c_collection_products_title_key AS c_collection_products_title_key,
    c.c_collection_products_summary_key AS c_collection_products_summary_key,
    c.c_collection_default_gender AS c_collection_default_gender,
    c.c_collection_channel AS c_collection_channel,
    c.c_collection_about_title_key AS c_collection_about_title_key,
    c.c_collection_about_copy_key AS c_collection_about_copy_key,
    c.c_collection_about_handle_key AS c_collection_about_handle_key,
    c.c_collection_about_target_url_key AS c_collection_about_target_url_key,
    c.c_collection_promo_copy_key AS c_collection_promo_copy_key,
    c.c_collection_promo_cta_copy_key AS c_collection_promo_cta_copy_key,
    c.c_collection_promo_target_url_key AS c_collection_promo_target_url_key,
    c.c_collection_subheading_key AS c_collection_subheading_key,
    c.c_collection_publish_date AS c_collection_publish_date,
    s1.str_value AS c_collection_title,
    s2.str_value AS c_collection_summary,
    s3.str_value AS c_collection_overview_title,
    s4.str_value AS c_collection_overview_summary,
    s5.str_value AS c_collection_workouts_title,
    s6.str_value AS c_collection_workouts_summary,
    s7.str_value AS c_collection_workouts_two_title,
    s8.str_value AS c_collection_workouts_two_summary,
    s9.str_value AS c_collection_heading,
    s10.str_value AS c_collection_training_note,
    s11.str_value AS c_collection_attribution_name,
    s12.str_value AS c_collection_attribution_title,
    s13.str_value AS c_collection_product_title,
    s14.str_value AS c_collection_product_summary,
    s15.str_value AS c_collection_about_title,
    s16.str_value AS c_collection_about_copy,
    s17.str_value AS c_collection_about_handle,
    s18.str_value AS c_collection_about_target_url,
    s19.str_value AS c_collection_promo_copy,
    s20.str_value AS c_collection_promo_cta_copy,
    s21.str_value AS c_collection_promo_target_url,
    s22.str_value AS c_collection_subheading,
    s23.str_value AS c_collection_workouts_three_title,
    s24.str_value AS c_collection_workouts_three_summary
    FROM ntc_collection AS c
    LEFT JOIN ntc_string AS s1 ON (s1.str_key == c_collection_title_key)
    LEFT JOIN ntc_string AS s2 ON (s2.str_key == c_collection_summary_key)
    LEFT JOIN ntc_string AS s3 ON (s3.str_key == c_collection_overview_title_key)
    LEFT JOIN ntc_string AS s4 ON (s4.str_key == c_collection_overview_summary_key)
    LEFT JOIN ntc_string AS s5 ON (s5.str_key == c_collection_workouts_title_key)
    LEFT JOIN ntc_string AS s6 ON (s6.str_key == c_collection_workouts_summary_key)
    LEFT JOIN ntc_string AS s7 ON (s7.str_key == c_collection_workouts_two_title_key)
    LEFT JOIN ntc_string AS s8 ON (s8.str_key == c_collection_workouts_two_summary_key)
    LEFT JOIN ntc_string AS s9 ON (s9.str_key == c_collection_heading_key)
    LEFT JOIN ntc_string AS s10 ON (s10.str_key == c_collection_training_note_key)
    LEFT JOIN ntc_string AS s11 ON (s11.str_key == c_collection_attribution_name_key)
    LEFT JOIN ntc_string AS s12 ON (s12.str_key == c_collection_attribution_title_key)
    LEFT JOIN ntc_string AS s13 ON (s13.str_key == c_collection_products_title_key)
    LEFT JOIN ntc_string AS s14 ON (s14.str_key == c_collection_products_summary_key)
    LEFT JOIN ntc_string AS s15 ON (s15.str_key == c_collection_about_title_key)
    LEFT JOIN ntc_string AS s16 ON (s16.str_key == c_collection_about_copy_key)
    LEFT JOIN ntc_string AS s17 ON (s17.str_key == c_collection_about_handle_key)
    LEFT JOIN ntc_string AS s18 ON (s18.str_key == c_collection_about_target_url_key)
    LEFT JOIN ntc_string AS s19 ON (s19.str_key == c_collection_promo_copy_key)
    LEFT JOIN ntc_string AS s20 ON (s20.str_key == c_collection_promo_cta_copy_key)
    LEFT JOIN ntc_string AS s21 ON (s21.str_key == c_collection_promo_target_url_key)
    LEFT JOIN ntc_string AS s22 ON (s22.str_key == c_collection_subheading_key)
    LEFT JOIN ntc_string AS s23 ON (s23.str_key == c_collection_workouts_three_title_key)
    LEFT JOIN ntc_string AS s24 ON (s24.str_key == c_collection_workouts_three_summary_key);
