--tables
CREATE TABLE IF NOT EXISTS ntc_athlete (
    a_athlete_id TEXT NOT NULL,
    a_name_key TEXT NOT NULL,
    a_title_key TEXT NOT NULL,
    a_tagline_key TEXT NOT NULL,
    a_workout_title_key TEXT NOT NULL,
    a_workout_summary_key TEXT NOT NULL,
    a_video_title_key TEXT NOT NULL,
    a_video_subhead_key TEXT NOT NULL,
    a_subtitles_key TEXT NOT NULL,
    a_channel_title_key TEXT NOT NULL,
    a_channel_id TEXT NOT NULL,
    a_product_title_key TEXT NOT NULL,
    a_gender INTEGER NOT NULL DEFAULT 1,
    a_workout_ids TEXT NOT NULL,
    UNIQUE (a_athlete_id) ON CONFLICT REPLACE);

CREATE TABLE IF NOT EXISTS ntc_athlete_product (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    p_image_url TEXT NOT NULL,
    p_name_key TEXT NOT NULL,
    p_description_key TEXT NOT NULL,
    p_target TEXT NOT NULL, p_gender INTEGER NOT NULL DEFAULT 1,
    a_athlete_id TEXT NOT NULL,
    FOREIGN KEY( a_athlete_id) REFERENCES ntc_athlete(a_athlete_id) ON DELETE CASCADE );

CREATE TABLE IF NOT EXISTS ntc_athlete_theme (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    t_body_color TEXT NOT NULL,
    t_header_color TEXT NOT NULL,
    t_background_color TEXT NOT NULL,
    a_athlete_id TEXT NOT NULL,
    FOREIGN KEY (a_athlete_id) REFERENCES ntc_athlete (a_athlete_id) ON DELETE CASCADE);

CREATE TABLE IF NOT EXISTS ntc_athlete_threads (
    t_id TEXT NOT NULL PRIMARY KEY,
    t_thread_id TEXT NOT NULL,
    t_interest_id TEXT NOT NULL,
    t_thread_name TEXT NOT NULL,
    t_image_url TEXT NOT NULL,
    t_title TEXT NOT NULL,
    t_thread_active BOOLEAN NOT NULL,
    a_athlete_id TEXT NOT NULL,
    FOREIGN KEY( a_athlete_id) REFERENCES ntc_athlete(a_athlete_id) ON DELETE CASCADE );

--views
CREATE VIEW IF NOT EXISTS v_ntc_athlete AS
    SELECT a.a_athlete_id AS a_athlete_id,
    a.a_name_key AS a_name_key,
    a.a_title_key AS a_title_key,
    a.a_tagline_key AS a_tagline_key,
    a.a_workout_summary_key AS a_workout_summary_key,
    a.a_workout_title_key AS a_workout_title_key,
    a.a_video_title_key AS a_video_title_key,
    a.a_video_subhead_key AS a_video_subhead_key,
    a.a_subtitles_key AS a_subtitles_key,
    a.a_channel_title_key AS a_channel_title_key,
    a.a_channel_id AS a_channel_id,
    a.a_product_title_key AS a_product_title_key,
    a.a_gender AS a_gender,
    a.a_workout_ids AS a_workout_ids,
    s1.str_value AS a_name,
    s2.str_value AS a_title,
    s3.str_value AS a_tagline,
    s4.str_value AS a_workout_summary,
    s9.str_value AS a_workout_title,
    s5.str_value AS a_video_title,
    s10.str_value AS a_channel_title,
    s6.str_value AS a_video_subhead,
    s8.str_value AS a_product_title
    FROM ntc_athlete AS a
    LEFT JOIN ntc_string AS s1 ON (s1.str_key = a_name_key)
    LEFT JOIN ntc_string AS s2 ON (s2.str_key = a_title_key)
    LEFT JOIN ntc_string AS s3 ON (s3.str_key = a_tagline_key)
    LEFT JOIN ntc_string AS s4 ON (s4.str_key = a_workout_summary_key)
    LEFT JOIN ntc_string AS s5 ON (s5.str_key = a_video_title_key)
    LEFT JOIN ntc_string AS s6 ON (s6.str_key = a_video_subhead_key)
    LEFT JOIN ntc_string AS s8 ON (s8.str_key = a_product_title_key)
    LEFT JOIN ntc_string AS s9 ON (s9.str_key = a_workout_title_key)
    LEFT JOIN ntc_string AS s10 ON (s10.str_key = a_channel_title_key);

CREATE VIEW IF NOT EXISTS v_ntc_athlete_product AS
    SELECT  p.p_image_url AS p_image_url,
    p.p_name_key AS p_name_key,
    p.p_description_key AS p_description_key,
    p.p_target AS p_target,
    p.p_gender AS p_gender,
    p.a_athlete_id AS a_athlete_id,
    s1.str_value AS a_athlete_product_name,
    s2.str_value AS a_athlete_product_description
    FROM ntc_athlete_product AS p
    LEFT JOIN ntc_string AS s1 ON (s1.str_key = p_name_key)
    LEFT JOIN ntc_string AS s2 ON (s2.str_key = p_description_key);
