--views
CREATE VIEW IF NOT EXISTS v_ntc_workout AS SELECT  w.w_workout_id AS w_workout_id,  w.w_estimated_rpe AS w_estimated_rpe,  w.w_estimated_fuel AS w_estimated_fuel,  w.w_estimated_kcal AS w_estimated_kcal,  w.w_is_benchmark AS w_is_benchmark,  w.w_duration_sec AS w_duration_sec,  w.w_estimated_duration_sec AS w_estimated_duration_sec,  w.w_focus AS w_focus,  w.w_intensity AS w_intensity,  w.w_type AS w_type,  w.w_level AS w_level,  w.w_equipment AS w_equipment,  w.w_name_key AS w_name_key,  w.w_athlete_key AS w_athlete_key,  w.w_author_key AS w_author_key,  w.w_quote_key AS w_quote_key,  w.w_content_version AS w_content_version,  s1.str_value AS w_name,  s2.str_value AS w_author,  s3.str_value AS w_quote,  s4.str_value AS w_athlete,  CASE WHEN (f.wf_workout_id NOTNULL) THEN "1" ELSE "0" END AS w_is_favorite FROM ntc_workout AS w LEFT JOIN ntc_string AS s1 ON (s1.str_key = w_name_key) LEFT JOIN ntc_string AS s2 ON (s2.str_key = w_author_key) LEFT JOIN ntc_string AS s3 ON (s3.str_key = w_quote_key) LEFT JOIN ntc_string AS s4 ON (s4.str_key = w_athlete_key) LEFT JOIN ntc_workout_favorite AS f ON f.wf_workout_id = w.w_workout_id ;

CREATE VIEW IF NOT EXISTS v_drills_strings AS SELECT d_drill_id, d_name_key, d_subtitle_key, d_type, d_metric_type, d_metric_value, d_est_duration_sec, d_transition_sec, dac_offset_sec, dac_asset_name, s1.str_value AS d_name, s2.str_value AS d_subtitle FROM ntc_drill AS d  LEFT JOIN ntc_string AS s1 ON (s1.str_key = d_name_key) LEFT JOIN ntc_string AS s2 ON (s2.str_key = d_subtitle_key) LEFT JOIN ntc_drill_audio_clip AS ac ON d.d_drill_id = ac.dac_d_drill_id;

CREATE VIEW IF NOT EXISTS v_drills_sections_workouts AS SELECT ws_w_workout_id AS ws_w_workout_id, s_section_id, ws_index, s.s_name_key AS s_name_key, str.str_value AS sec_name_value FROM ntc_workout_section AS ws LEFT JOIN ntc_section AS s ON  ( ws.ws_s_section_id = s.s_section_id)  LEFT JOIN ntc_string AS str ON  ( s.s_name_key = str.str_key);

CREATE VIEW IF NOT EXISTS v_workout_equipment_strings AS SELECT we_w_workout_id, we_index_order, we_s_key, str_value AS we_s_value FROM ntc_workout_equipment LEFT JOIN ntc_string AS s ON (s.str_key = we_s_key);

CREATE VIEW IF NOT EXISTS v_ntc_workout_tags_strings AS SELECT wt_workout_id, wt_string_id AS wt_s_id, s.str_value AS wt_s_value FROM ntc_workout_tags LEFT JOIN ntc_string AS s ON (s.str_key = wt_string_id);

CREATE VIEW IF NOT EXISTS v_workout_benefits_strings AS SELECT wb_workout_id, wb_index_order, wb_s_key, str_value AS wb_s_value FROM ntc_workout_benefit LEFT JOIN ntc_string AS s ON (s.str_key = wb_s_key);


--search table
CREATE TABLE IF NOT EXISTS ntc_workout_indices (_id INTEGER PRIMARY KEY AUTOINCREMENT, w_workout_id TEXT,wi_s_id TEXT NOT NULL,wi_s_value TEXT, wi_index_type INTEGER NOT NULL, w_duration_sec INTEGER NON NULL DEFAULT 0, CONSTRAINT name_unique_on_type UNIQUE (wi_s_id,wi_index_type, w_workout_id) ON CONFLICT REPLACE) ;

CREATE INDEX IF NOT EXISTS i_workout_indices_name ON ntc_workout_indices(wi_s_value);

--search triggers
CREATE TRIGGER IF NOT EXISTS t_wi_workout_insert_name AFTER INSERT ON ntc_workout FOR EACH ROW  BEGIN  INSERT INTO ntc_workout_indices( w_workout_id, wi_index_type, w_duration_sec, wi_s_id) VALUES (NEW.w_workout_id, 0, NEW.w_duration_sec, NEW.w_name_key);END;

CREATE TRIGGER IF NOT EXISTS t_wi_workout_insert_athlete AFTER INSERT ON ntc_workout FOR EACH ROW  WHEN NEW.w_athlete_key NOTNULL  BEGIN  INSERT INTO ntc_workout_indices( w_workout_id, wi_index_type, w_duration_sec, wi_s_id) VALUES (NEW.w_workout_id, 1, 0, NEW.w_athlete_key);END;

CREATE TRIGGER IF NOT EXISTS t_wi_workout_insert_author AFTER INSERT ON ntc_workout FOR EACH ROW  WHEN NEW.w_author_key NOTNULL  BEGIN  INSERT INTO ntc_workout_indices( w_workout_id, wi_index_type, w_duration_sec, wi_s_id) VALUES (NEW.w_workout_id, 2, 0, NEW.w_author_key);END;

CREATE TRIGGER IF NOT EXISTS t_wi_workout_delete AFTER DELETE ON ntc_workout FOR EACH ROW  BEGIN  DELETE FROM ntc_workout_indices WHERE w_workout_id = OLD.w_workout_id; END;

CREATE TRIGGER IF NOT EXISTS t_wi_workout_equipment_insert AFTER INSERT ON ntc_workout_equipment FOR EACH ROW  BEGIN INSERT INTO ntc_workout_indices( w_workout_id, wi_index_type, w_duration_sec, wi_s_id) VALUES (NEW.we_w_workout_id, 3, 0, NEW.we_s_key);  END;

CREATE TRIGGER IF NOT EXISTS t_wi_workout_equipment_delete AFTER DELETE ON ntc_workout_equipment FOR EACH ROW BEGIN DELETE FROM ntc_workout_indices WHERE w_workout_id = OLD.we_w_workout_id AND wi_s_id = OLD.we_s_key; END;

CREATE TRIGGER IF NOT EXISTS t_wi_workout_tag_insert AFTER INSERT ON ntc_workout_tags FOR EACH ROW  BEGIN  INSERT INTO ntc_workout_indices( w_workout_id, wi_index_type, w_duration_sec, wi_s_id) VALUES (NEW.wt_workout_id, 6, 0, NEW.wt_string_id); END;

CREATE TRIGGER IF NOT EXISTS t_wi_workout_tag_delete AFTER DELETE ON ntc_workout_tags FOR EACH ROW  BEGIN  DELETE FROM ntc_workout_indices WHERE w_workout_id = OLD.wt_workout_id AND wi_index_type = 6 AND wi_s_id = OLD.wt_string_id; END;

CREATE TRIGGER IF NOT EXISTS t_wi_workout_drill_insert AFTER INSERT ON ntc_section_drill FOR EACH ROW  BEGIN  INSERT INTO ntc_workout_indices( w_workout_id, wi_index_type, wi_s_id) SELECT ws.ws_w_workout_id, 4, d.d_name_key FROM ntc_drill as d LEFT JOIN ntc_section_drill as sd ON d.d_drill_id = sd.sd_drill_id LEFT JOIN ntc_section as s ON s.s_section_id = sd.sd_section_id LEFT JOIN ntc_workout_section as ws ON s.s_section_id = ws.ws_s_section_id WHERE d.d_drill_id = NEW.sd_drill_id; END;

CREATE TRIGGER IF NOT EXISTS t_wi_workout_drill_delete AFTER DELETE ON ntc_drill FOR EACH ROW  WHEN 0 = (SELECT Count() FROM ntc_drill WHERE d_name_key = OLD.d_name_key) BEGIN  DELETE FROM ntc_workout_indices WHERE wi_index_type = 4 AND wi_s_id = OLD.d_name_key; END;

CREATE TRIGGER IF NOT EXISTS t_wi_workout_benefit_insert AFTER INSERT ON ntc_workout_benefit FOR EACH ROW  BEGIN  INSERT INTO ntc_workout_indices( w_workout_id, wi_index_type, w_duration_sec, wi_s_id) VALUES (NEW.wb_workout_id, 5, 0, NEW.wb_s_key) ; END;

CREATE TRIGGER IF NOT EXISTS t_wi_workout_benefit_delete AFTER DELETE ON ntc_workout_benefit FOR EACH ROW  BEGIN  DELETE FROM ntc_workout_indices WHERE w_workout_id = OLD.wb_workout_id AND wi_index_type = 5 AND wi_s_id = OLD.wb_s_key; END;

CREATE TRIGGER IF NOT EXISTS t_wi_string_insert AFTER INSERT ON ntc_string FOR EACH ROW  BEGIN  UPDATE ntc_workout_indices SET wi_s_value = NEW.str_value WHERE wi_s_id = NEW.str_key;  END;
