--base NTC tables
CREATE TABLE IF NOT EXISTS ntc_pending_manifest (remote_url TEXT NOT NULL,
    etag TEXT NOT NULL,
    download_epoch INTEGER  NOT NULL,
    master_bundle_id TEXT NOT NULL,
    manifest_inserted INTEGER NOT NULL,
    master_bundle_downloaded INTEGER NOT NULL,
    master_bundle_inserted INTEGER NOT NULL,
    created_at LONG NOT NULL DEFAULT 0,
    UNIQUE (remote_url, etag) ON CONFLICT REPLACE );

CREATE TABLE IF NOT EXISTS ntc_manifest (
    remote_url TEXT NOT NULL,
    etag TEXT NOT NULL,
    insert_epoch INTEGER  NOT NULL,
    master_bundle_id TEXT NOT NULL,
    stored_in_dropship INTEGER NOT NULL,
    workouts_asset_id TEXT NOT NULL,
    cues_asset_id TEXT NOT NULL,
    localized_strings_asset_id TEXT NOT NULL,
    featured_workouts_asset_id TEXT NOT NULL,
    version FLOAT NOT NULL DEFAULT 0,
    created_at LONG NON NULL DEFAULT 0,
    UNIQUE (remote_url, etag) ON CONFLICT REPLACE );

CREATE TABLE IF NOT EXISTS ntc_workout (
    w_workout_id TEXT NOT NULL PRIMARY KEY ON CONFLICT REPLACE,
    w_estimated_rpe REAL DEFAULT 0 NOT NULL,
    w_estimated_fuel INTEGER DEFAULT 0 NOT NULL,
    w_estimated_kcal INTEGER DEFAULT 0 NOT NULL,
    w_is_benchmark INTEGER DEFAULT 0 NOT NULL,
    w_duration_sec INTEGER DEFAULT 0 NOT NULL,
    w_estimated_duration_sec INTEGER DEFAULT 0 NOT NULL,
    w_focus INTEGER DEFAULT 0 NOT NULL,
    w_intensity INTEGER DEFAULT 0 NOT NULL,
    w_type INTEGER DEFAULT 0 NOT NULL,
    w_level INTEGER DEFAULT 0 NOT NULL,
    w_equipment INTEGER DEFAULT 0 NOT NULL,
    w_name_key TEXT NOT NULL,
    w_athlete_key TEXT,
    w_author_key TEXT,
    w_quote_key TEXT,
    w_content_version NUMBER NOT NULL);

CREATE INDEX IF NOT EXISTS i_ntc_workout_name_key ON ntc_workout(w_name_key);

CREATE INDEX IF NOT EXISTS i_ntc_workout_duration ON ntc_workout(w_duration_sec, w_name_key);

CREATE TABLE IF NOT EXISTS ntc_section (
        s_section_id TEXT NOT NULL,
        s_name_key TEXT NOT NULL,
        UNIQUE (s_section_id) ON CONFLICT IGNORE);

CREATE INDEX IF NOT EXISTS i_ntc_section_s_id ON ntc_section(s_section_id);

CREATE TABLE IF NOT EXISTS ntc_drill (
    d_drill_id TEXT NOT NULL,
    d_name_key TEXT NOT NULL,
    d_subtitle_key TEXT,
    d_type INTEGER NOT NULL,
    d_metric_type INTEGER NOT NULL,
    d_metric_value REAL NOT NULL,
    d_est_duration_sec INTEGER NOT NULL DEFAULT 0,
    d_transition_sec INTEGER NOT NULL DEFAULT 0,
    UNIQUE (d_drill_id) ON CONFLICT REPLACE);

CREATE INDEX IF NOT EXISTS i_ntc_drills ON ntc_drill(d_drill_id);

CREATE TABLE IF NOT EXISTS ntc_string (
    str_key TEXT NOT NULL,
    str_value TEXT NOT NULL,
    CONSTRAINT ntc_string_unique UNIQUE (str_key) ON CONFLICT REPLACE );

CREATE UNIQUE INDEX IF NOT EXISTS i_ntc_string_id ON ntc_string(str_key);

CREATE TABLE IF NOT EXISTS ntc_workout_favorite (
    wf_workout_id TEXT NOT NULL,
    wf_created_at LONG NOT NULL DEFAULT 0,
    UNIQUE (wf_workout_id) ON CONFLICT REPLACE );

CREATE TABLE IF NOT EXISTS ntc_featured_workout (
    wf_w_workout_id TEXT NOT NULL,
    wf_start_time TEXT NOT NULL,
    FOREIGN KEY(wf_w_workout_id) REFERENCES ntc_workout(w_workout_id));

CREATE TABLE IF NOT EXISTS ntc_workout_section (
    ws_w_workout_id TEXT NOT NULL,
    ws_s_section_id TEXT NOT NULL,
    ws_index INTEGER NOT NULL,
    FOREIGN KEY(ws_w_workout_id) REFERENCES ntc_workout(w_workout_id),
    FOREIGN KEY(ws_s_section_id) REFERENCES ntc_section(s_section_id),
    UNIQUE (ws_w_workout_id, ws_s_section_id) ON CONFLICT REPLACE);

CREATE INDEX IF NOT EXISTS i_ntc_workout_sections ON ntc_workout_section(ws_w_workout_id,ws_s_section_id);

CREATE TABLE IF NOT EXISTS ntc_section_drill (sd_section_id TEXT NOT NULL,sd_index INTEGER NOT NULL,sd_drill_id INTEGER NOT NULL);

CREATE INDEX IF NOT EXISTS i_ntc_drills_section_id_drill_id ON ntc_section_drill(sd_section_id, sd_drill_id);

CREATE INDEX IF NOT EXISTS i_ntc_workout_drill_sections ON ntc_section_drill(sd_drill_id);

CREATE TABLE IF NOT EXISTS ntc_drill_audio_clip (
    dac_asset_name TEXT NOT NULL,
    dac_d_drill_id TEXT NOT NULL,
    dac_offset_sec REAL NOT NULL DEFAULT 0,
    dac_audio_type TEXT NOT NULL DEFAULT 'invalid',
    UNIQUE (dac_d_drill_id, dac_asset_name)  ON CONFLICT REPLACE );

CREATE INDEX IF NOT EXISTS i_ntc_audio_clip ON ntc_drill_audio_clip(dac_d_drill_id, dac_offset_sec);

CREATE TABLE IF NOT EXISTS ntc_workout_equipment (
    we_w_workout_id TEXT NOT NULL,
    we_s_key TEXT NOT NULL,
    we_index_order INTEGER NOT NULL,
    UNIQUE (we_w_workout_id,we_s_key) ON CONFLICT REPLACE );

CREATE TABLE IF NOT EXISTS ntc_workout_benefit (
    wb_workout_id TEXT NOT NULL,
    wb_s_key TEXT NOT NULL,
    wb_index_order INTEGER NOT NULL,
    UNIQUE (wb_workout_id,wb_s_key) ON CONFLICT REPLACE );

CREATE TABLE IF NOT EXISTS ntc_workout_recommended (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    w_workout_id TEXT NOT NULL,
    wr_created_at LONG NOT NULL DEFAULT 0,
    wr_gender INTEGER,
    wr_personalized BOOLEAN NOT NULL DEFAULT FALSE,
    wr_name_id TEXT,
    wr_version TEXT,
    wr_source INTEGER NOT NULL DEFAULT 0, wr_workout_level INTEGER NOT NULL DEFAULT 0);

CREATE TABLE IF NOT EXISTS ntc_workout_tags (
    _id INTEGER PRIMARY KEY AUTOINCREMENT,
    wt_string_id TEXT NOT NULL,
    wt_workout_id TEXT NOT NULL  );
